@@ -4,7 +4,7 @@ from django.utils.html import strip_spaces_between_tags as minify_html
 
 class MinifyHTMLMiddleware(object):
     def process_response(self, request, response):
-        if 'text/html' in response['Content-Type']:
+        if response.has_header('Content-Type') and 'text/html' in response['Content-Type']:
             try:
                 response.content = minify_html(response.content.strip())
             except DjangoUnicodeDecodeError:
