@@ -4,8 +4,8 @@ try:
     from staticfiles import finders
     from staticfiles.storage import CachedFilesMixin, StaticFilesStorage
 except ImportError:
-    from django.contrib.staticfiles import finders # noqa
-    from django.contrib.staticfiles.storage import CachedFilesMixin, StaticFilesStorage # noqa
+    from django.contrib.staticfiles import finders  # noqa
+    from django.contrib.staticfiles.storage import CachedFilesMixin, StaticFilesStorage  # noqa
 
 from django.core.exceptions import ImproperlyConfigured
 from django.core.files.storage import get_storage_class
@@ -88,7 +88,7 @@ class BaseFinderStorage(PipelineStorage):
         return path
 
     def exists(self, name):
-        exists = self.finders.find(name) != None
+        exists = self.finders.find(name) is not None
         if not exists:
             return super(BaseFinderStorage, self).exists(name)
         return exists
